import { NextResponse } from "next/server"
import type { NextRequest } from "next/server"
import { verifyAuth } from "./utils/auth"

export async function middleware(request: NextRequest) {
  // Only apply to admin routes
  if (request.nextUrl.pathname.startsWith("/admin")) {
    const token = request.cookies.get("auth-token")?.value

    // If there's no token, redirect to login
    if (!token) {
      return NextResponse.redirect(new URL("/login", request.url))
    }

    // Verify the token
    const authResult = await verifyAuth(token)

    if (!authResult.success) {
      return NextResponse.redirect(new URL("/login", request.url))
    }
  }

  return NextResponse.next()
}

export const config = {
  matcher: ["/admin/:path*"],
}

